**Plugin ID:** <!--{{ pluginID }}-->  
**Severity:** <!--{{ risk_factor }}-->  
**Port:** <!--{{ port }}-->  
**Service:** <!--{{ svc_name|default:"n/a" }}-->  

<!--{{ plugin_output|default:"" }}-->

## Description
<!--{{ description }}-->

## Solution
<!--{{ solution }}-->